Learn R Programming

bedr (version 1.0.2)

bedr.subtract.region: subtracts features or ranges in object b from object a

Description

subtracts features or ranges in object b from object a

Usage

bedr.subtract.region( x, y, fraction.overlap = 1/1e9, remove.whole.feature = TRUE, check.zero.based = TRUE, check.chr = TRUE, check.valid = TRUE, check.sort = TRUE, check.merge = TRUE, verbose = TRUE )

Arguments

x
item a
y
item b
fraction.overlap
what portion of A to be considered an overlap
remove.whole.feature
should whole feature be removed
check.zero.based
should 0 based coordinates be checked
check.chr
should chr prefix be checked
check.valid
should the region be checkded for integerity
check.sort
check if region is sorted
check.merge
check if overlapping regions are merged
verbose
messages and checks

Value

Regions exclusive to one object of regions.

References

http://bedtools.readthedocs.org/en/latest/content/tools/subtract.html

Examples

Run this code
if (check.binary("bedtools")) {
index <- get.example.regions();

a <- index[[1]];
b <- index[[2]];
a <- bedr(engine = "bedtools", input = list(i = a), method = "sort", params = "");
b <- bedr(engine = "bedtools", input = list(i = b), method = "sort", params = "");
d <- bedr.subtract.region(a,b);
}

Run the code above in your browser using DataLab