Learn R Programming

bedr (version 1.0.2)

download.datasets: Download some useful datasets

Description

Download some useful datasets. Some functions such as plotting and fasta querying require additional data.

Usage

download.datasets(datasets = "all", data.dir = paste0(Sys.getenv("HOME"), "/bedr/data"))

Arguments

datasets
A list of datasets to download. Defaults to "all" i.e. c("refgene","hg19","b37","hugo", "cosmic","clinvar")
data.dir
A directory to put the data. Defaults to ~/bedr/data

Value

some datasets.

Details

External datasets are required for some bedr functionality. For example, plotting intersections based on genes, get.fasta, bed2vcf and validate.gene.names. If these datasets already exist you can simply place symlinks in a directory and use bedr.setup() to define the data.dir.

Examples

Run this code
#download.datasets("cosmic")

Run the code above in your browser using DataLab