Learn R Programming

bedr (version 1.0.2)

is.sorted.region: checks if region file is sorted

Description

checks if region file is sorted

Usage

is.sorted.region( x, method = "lex", engine = "unix", check.zero.based = TRUE, check.chr = TRUE, check.valid = TRUE, check.merge = TRUE, verbose = FALSE )

Arguments

x
The region index, bed file, or bed formatted object
method
lexicgraphical or natural, lex is required for many operations but natural is better for interpretation
engine
what analytical engine to use for sorting i.e. bedtools, bedops, gnu unix
check.zero.based
should 0 based coordinates be checked
check.chr
should chr prefix be checked
check.valid
check if region is valid
check.merge
check if region is merged
verbose
more words

Examples

Run this code
if (check.binary("bedtools")) {
index <- get.example.regions();

a <- index[[1]];

b <- is.sorted.region(a);
}

Run the code above in your browser using DataLab