Usage
bedr.merge.region(
x,
distance = 0,
list.names = TRUE,
number = FALSE,
stratify.by = NULL,
check.zero.based = TRUE,
check.chr = TRUE,
check.valid = TRUE,
check.sort = TRUE,
verbose = TRUE
);
Arguments
distance
maximum distance between regions to be merged. defaults to 0 which means overlapping or bookended features. note that you can use negative distances to enforce a minimum overlap.
list.names
output list of names for merged items
number
output number of merged items
stratify.by
a column name indicating the groups to stratify merging within i.e. gene name. merging will not happen between groups.
check.zero.based
should 0 based coordinates be checked
check.chr
should chr prefix be checked
check.valid
should the region be checkded for integerity
check.sort
should the sort order be checked
verbose
should log messages and checking take place